@@ -15,6 +15,8 @@ from datetime import datetime, timedelta
 from pathlib import Path
 from typing import List, Optional, Dict, Set
 from urllib.parse import ParseResult as URL
+from urllib.request import urlopen
+from urllib.error import URLError
 
 from dataclasses import dataclass
 
@@ -75,8 +77,8 @@ class RocketLeagueLauncherPreference:
     use_login_tricks: bool
 
 
-# By default, we will attempt Epic with no login tricks, then fall back to Steam.
-DEFAULT_LAUNCHER_PREFERENCE = RocketLeagueLauncherPreference(RocketLeagueLauncherPreference.EPIC, False)
+# By default, we will attempt Epic with login tricks, then fall back to Steam.
+DEFAULT_LAUNCHER_PREFERENCE = RocketLeagueLauncherPreference(RocketLeagueLauncherPreference.EPIC, True)
 
 
 @contextmanager
@@ -306,15 +308,39 @@ class SetupManager:
         if match_config.extension_config is not None and match_config.extension_config.python_file_path is not None:
             self.load_extension(match_config.extension_config.python_file_path)
 
+        try:
+            urlopen("http://google.com")
+            checked_environment_requirements = set()
+            online = True
+        except URLError:
+            print("The user is offline, skipping upgrade the bot requirements")
+            online = False
+
         for bundle in self.bot_bundles:
             if bundle is not None and bundle.use_virtual_environment:
-                builder = EnvBuilderWithRequirements(bundle=bundle)
+                do_post_setup = online
+
+                if do_post_setup:
+                    if bundle.requirements_file in checked_environment_requirements:
+                        do_post_setup = False
+                    else:
+                        checked_environment_requirements.add(bundle.requirements_file)
+
+                builder = EnvBuilderWithRequirements(bundle=bundle, do_post_setup=do_post_setup)
                 builder.create(Path(bundle.config_directory) / 'venv')
 
         for script_config in match_config.script_configs:
             script_config_bundle = get_script_config_bundle(script_config.config_path)
             if script_config_bundle.use_virtual_environment:
-                builder = EnvBuilderWithRequirements(bundle=script_config_bundle)
+                do_post_setup = online
+
+                if do_post_setup:
+                    if bundle.requirements_file in checked_environment_requirements:
+                        do_post_setup = False
+                    else:
+                        checked_environment_requirements.add(bundle.requirements_file)
+                
+                builder = EnvBuilderWithRequirements(bundle=script_config_bundle, do_post_setup=do_post_setup)
                 builder.create(Path(script_config_bundle.config_directory) / 'venv')
 
         self.match_config = match_config
@@ -409,8 +435,8 @@ class SetupManager:
 
     def launch_bot_process_helper(self, early_starters_only=False, match_config: MatchConfig = None):
         # Start matchcomms here as it's only required for the bots.
-        self.kill_matchcomms_server()
-        self.matchcomms_server = launch_matchcomms_server()
+        if not self.matchcomms_server:
+            self.matchcomms_server = launch_matchcomms_server()
         self.bot_processes = {ind: proc for ind, proc in self.bot_processes.items() if proc.is_alive()}
 
         num_started = 0
@@ -498,8 +524,14 @@ class SetupManager:
             if script_config_bundle.use_virtual_environment:
                 executable = str(Path(script_config_bundle.config_directory) / 'venv' / 'Scripts' / 'python.exe')
 
-            process = subprocess.Popen([executable, script_config_bundle.script_file],
-                                       cwd=Path(script_config_bundle.config_directory).parent)
+            process = subprocess.Popen(
+                [
+                    executable,
+                    script_config_bundle.script_file, 
+                    '--matchcomms-url', self.matchcomms_server.root_url.geturl()
+                ],
+                cwd=Path(script_config_bundle.config_directory).parent
+            )
             self.logger.info(f"Started script with pid {process.pid} using {process.args}")
             self.script_processes[process.pid] = process
             scripts_started += 1
