@@ -4,14 +4,17 @@
 # 3) we can import it into your module module
 # https://stackoverflow.com/questions/458550/standard-way-to-embed-version-into-python-package
 
-__version__ = '1.56.2'
+__version__ = '1.58.2'
 
 release_notes = {
-    '1.56.2': """
-    Support for Gridiron mode!
-    
-    Passing matchcomms-url to Java and C# bots as a command line argument.
-    See https://github.com/RLBot/RLBot/wiki/Matchcomms for more information.
+    '1.58.2': """
+    Bots with python virtual environments will start up much faster. - VirxEC
+    Bots can now have descriptive tags for better organization in RLBotGUI. - Darxeal
+    Fixing bug where python launch scripts stopped working for Epic users. - tarehart
+    Experimental fix for games with many scratch bots. - tarehart
+    """,
+    '1.57.0': """
+    Scripts now have access to the matchcomms system, thanks to Will!
     """,
     '1.55.7': """
     Using sockets for match start, lifting the restrictions on max players when using flatbuffers,
